types

package
v0.0.0-...-f4b7103 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 1, 2022 License: GPL-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Copyright © 2022 uscan team

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

Index

Constants

const (
	Erc20Flag   byte = 0x80
	Erc721Flag  byte = 0x40
	Erc1155Flag byte = 0x20
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Account

type Account struct {
	Erc20   bool
	Erc721  bool
	Erc1155 bool
	Balance uint64
	Code    []byte
}

func (*Account) Marshal

func (a *Account) Marshal() ([]byte, error)

func (*Account) Unmarshal

func (a *Account) Unmarshal(bin []byte) error

type Deserializer

type Deserializer interface {
	Unmarshal(bin []byte) error
}

type Serializer

type Serializer interface {
	Marshal() ([]byte, error)
}

Jump to